@@ -1,67 +1,69 @@
 var languageNames = {
 "en-US": "Английски (САЩ)",
+"sq": "Албански",
 "am": "Амхарски",
 "ar": "Арабски",
 "ast": "Астурски",
-"bg": "Български",
 "bn": "Бенгалски",
 "bn-IN": "Бенгалски (Индия)",
-"bo": "Тибетски",
 "bs": "Босненски",
+"bg": "Български",
 "ca": "Каталонски",
-"ca-valencia": "Валенсийски каталонски",
+"ca-valencia": "Catalan (Valencia)",
+"zh-CN": "Китайски (опростен)",
+"zh-TW": "Китайски (традиционен)",
+"hr": "Хърватски",
 "cs": "Чешки",
 "da": "Датски",
-"de": "Немски",
+"nl": "Нидерландски",
 "dz": "Дзонха",
-"el": "Гръцки",
 "en-GB": "Английски (Обединено кралство)",
 "en-ZA": "Английски (Южна Африка)",
 "eo": "Есперанто",
-"es": "Испански",
 "et": "Естонски",
 "eu": "Баски",
 "fi": "Финландски",
 "fr": "Френски",
 "gl": "Галисийски",
+"ka": "Грузински",
+"de": "Немски",
+"el": "Гръцки",
 "gu": "Гуджарати",
 "he": "Иврит",
 "hi": "Хинди",
-"hr": "Хърватски",
 "hu": "Унгарски",
 "id": "Индонезийски",
 "is": "Исландски",
 "it": "Италиански",
 "ja": "Японски",
-"ka": "Грузински",
 "km": "Кхмерски",
 "ko": "Корейски",
 "lo": "Лаоски",
-"lt": "Литовски",
 "lv": "Латвийски",
+"lt": "Литовски",
 "mk": "Македонски",
-"nb": "Норвежки, букмол",
 "ne": "Непалски",
-"nl": "Холандски",
 "nn": "Норвежки, ниношк",
+"nb": "Норвежки, букмол",
 "om": "Оромо",
 "pl": "Полски",
 "pt": "Португалски",
-"pt-BR": "Бразилски португалски",
+"pt-BR": "Portuguese (Brazil)",
 "ro": "Румънски",
 "ru": "Руски",
-"si": "Синхала",
 "sid": "Сидама",
+"si": "Синхала",
 "sk": "Словашки",
 "sl": "Словенски",
-"sq": "Албански",
+"dsb": "Sorbian (Lower)",
+"hsb": "Sorbian (Upper)",
+"es": "Испански",
 "sv": "Шведски",
-"ta": "Тамилски",
 "tg": "Таджикски",
+"ta": "Тамилски",
+"bo": "Тибетски",
 "tr": "Турски",
 "ug": "Уйгурски",
 "uk": "Украински",
 "vi": "Виетнамски",
-"zh-CN": "Китайски (опростен)",
-"zh-TW": "Китайски (традиционен)",
 };
